@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -79,6 +79,31 @@ flock($fileaperto,3);
 fclose($fileaperto);
 } # fine if ($chiave_codifica_xor)
 
+if ($num_colonna_gol_segnati and ($bonus_gol_portiere or $bonus_gol_difensore or $bonus_gol_centrocampista or $bonus_gol_fantasista or $bonus_gol_attaccante)) $calcola_bonus = 1;
+else $calcola_bonus = 0;
+if ($calcola_bonus) {
+$ruolo = array();
+if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") $considera_fantasisti_come = "F";
+$calciatori_completi = file("$percorso_cartella_voti/calciatori.txt");
+$num_calciatori_completi = count($calciatori_completi);
+for ($num1 = 0 ; $num1 < $num_calciatori_completi ; $num1++) {
+$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori_completi[$num1]);
+$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
+$numero = togli_acapo($numero);
+if ($num_colonna_attributo_fantasista) $attr_fantasista = $dati_calciatore[($num_colonna_attributo_fantasista-1)];
+else $attr_fantasista = 0;
+$s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
+$s_ruolo = togli_acapo($s_ruolo);
+$ruolo[$numero] = $s_ruolo;
+if ($s_ruolo == $simbolo_fantasista_file_calciatori) $ruolo[$numero] = $considera_fantasisti_come;
+if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo[$numero] = "P";
+if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo[$numero] = "D";
+if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo[$numero] = "C";
+if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo[$numero] = "A";
+if ($attr_fantasista) $ruolo[$numero] = "F";
+} # fine for $num1
+} # fine if ($calcola_bonus)
+
 # prendo i voti dal file
 $voti = file("$percorso_cartella_voti/voti$num_giornata_2_cifre.txt");
 $num_voti = count($voti);
@@ -90,6 +115,16 @@ $voto_calciatore = $dati_voto[($num_colonna_vototot_file_voti - 1)];
 $voto_calciatore = togli_acapo($voto_calciatore);
 $voto_calciatore = str_replace(",",".",$voto_calciatore);
 $voto_tot[$num_calciatore] = $voto_calciatore + 0.0;
+if ($calcola_bonus) {
+$gol_calciatore = (integer) togli_acapo($dati_voto[($num_colonna_gol_segnati - 1)]);
+if ($gol_calciatore) {
+if ($ruolo[$num_calciatore] == "P") $voto_tot[$num_calciatore] += $gol_calciatore * (double) $bonus_gol_portiere;
+if ($ruolo[$num_calciatore] == "D") $voto_tot[$num_calciatore] += $gol_calciatore * (double) $bonus_gol_difensore;
+if ($ruolo[$num_calciatore] == "C") $voto_tot[$num_calciatore] += $gol_calciatore * (double) $bonus_gol_centrocampista;
+if ($ruolo[$num_calciatore] == "F") $voto_tot[$num_calciatore] += $gol_calciatore * (double) $bonus_gol_fantasista;
+if ($ruolo[$num_calciatore] == "A") $voto_tot[$num_calciatore] += $gol_calciatore * (double) $bonus_gol_attaccante;
+} # fine if ($gol_calciatore)
+} # fine if ($calcola_bonus)
 $voto_giornale[$num_calciatore] = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
 $voto_giornale[$num_calciatore] = togli_acapo($voto_giornale[$num_calciatore]) + 0.0;
 } # fine for $num1
