@@ -69,12 +69,19 @@ $simbolo_fantasista_file_calciatori = "F";
 $simbolo_attaccante_file_calciatori = "A";
 $considera_fantasisti_come = "F";	# impostare a "F" per usare i fantasisti, "C" per considerarli centrocampisti, "A" attaccanti
 $num_colonna_squadra_file_calciatori = 0;	# opzionale, non c'è se impostato a 0
+$num_colonna_attributo_fantasista = 0;	# se il fantasista è assegnato come attributo (diverso da vuoto o 0)
 
 # 12) Composizione del file con i voti di giornata (dati/votiXX.txt)
 $separatore_campi_file_voti = ",";
 $num_colonna_numcalciatore_file_voti = 1;
 $num_colonna_vototot_file_voti = 4;
 $num_colonna_votogiornale_file_voti = 4;
+$num_colonna_gol_segnati = 0;	# opzionale, non c'è se impostato a 0
+$bonus_gol_portiere = 0;
+$bonus_gol_difensore = 0;
+$bonus_gol_centrocampista = 0;
+$bonus_gol_fantasista = 0; # applicato anche se fantasista è solo un attributo
+$bonus_gol_attaccante = 0;
 $chiave_codifica_xor = ""; # Inserire la chiave se il file è codificato con xor
 
 # 13) Posizione del file dei voti da copiare (se non viene copiato a mano), può
