@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_admin_errata == "NO") {
@@ -28,11 +29,11 @@ if ($pass_admin_errata == "NO") {
 
 $num_giornata = substr($giornata,8);
 
-if ($copia_file_voti and $posizione_file) {
-if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt")) {
-echo "file gi esistente, non copiato.";
+if ($copia_file_voti and $posizione_file and $num_giornata) {
+if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt") or preg_replace("/[0-9]*/","",$num_giornata) != "") {
+echo "file già esistente, non copiato.";
 $copiare = "NO";
-} # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
+} # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt") or...
 $lock = fopen("$percorso_cartella_dati/admin.lock","w+");
 flock($lock,2);
 if ($file_voti_zippato == "SI") {
@@ -70,7 +71,21 @@ fclose($filevoti);
 } # fine if ($copiare != "NO")
 flock($lock,3);
 fclose($lock);
-} # fine if ($copia_file_voti and $posizione_file)
+} # fine if ($copia_file_voti and $posizione_file and $num_giornata)
+
+elseif ($upload_file_voti and $num_giornata) {
+$errore = "NO";
+$file_voti = "$percorso_cartella_voti/voti$num_giornata.txt";
+if (preg_replace("/[0-9]*/","",$num_giornata) != "") $errore = "SI";
+if (@is_file($file_voti)) $errore = "SI";
+if (!$file_voti_upload) {
+if ($HTTP_POST_FILES['file_voti_upload']['tmp_name']) $file_voti_upload = $HTTP_POST_FILES['file_voti_upload']['tmp_name'];
+else if ($_FILES['file_voti_upload']['tmp_name']) $file_voti_upload = $_FILES['file_voti_upload']['tmp_name'];
+} # fine if (!$file_voti_upload)
+if (!move_uploaded_file($file_voti_upload,$file_voti)) $errore = "SI";
+if ($errore == "NO") echo "Ho fatto l'upload del file $file_voti.<br>";
+else echo"Non ho potuto fare l'upload del file.<br>";
+} # fine elseif ($upload_file_voti and $num_giornata)
 
 
 echo "<center><b>$giornata</b></center>";
@@ -141,7 +156,7 @@ $formazione = "formazione_$giocatore";
 $formazione = $$formazione;
 $num_linee_formazione = count($formazione);
 for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
-$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
+$formazione[$num2] = preg_replace("/ /","&nbsp;",$formazione[$num2]);
 $tab_formazioni .= $formazione[$num2]."<br>";
 } # fine for $num2
 $tab_formazioni .= "</td>
@@ -195,7 +210,7 @@ $punti[$dati_punteggio[0]] = $dati_punteggio[1];
 } # fine for $num1
 
 # calcolo la classifica fino a questa giornata
-$num_giornata = ereg_replace("giornata","",$giornata);
+$num_giornata = preg_replace("/giornata/","",$giornata);
 for ($num1 = $g_inizio_campionato ; $num1 < $num_giornata ; $num1++) {
 if (strlen($num1) == 1) $num1 = "0".$num1;
 $giornata_punti = "giornata$num1";
@@ -245,26 +260,26 @@ echo "<center>Giornata chiusa.</center><br>";
 
 else {
 if (@is_file("$percorso_cartella_voti/voti$num_giornata.txt")) {
-echo "<center><form method=\"post\" action=\"calcola_punti_giornata.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"calcola_punti_giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
 <input type=\"submit\" name=\"calcola\" value=\"Calcola i punteggi\">
-</form></center>";
+</form></center><br>";
 } # fine if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
 
 else {
 if ($prima_parte_pos_file_voti or $num_giornata_file_voti == "SI") {
 $posizione_file = $prima_parte_pos_file_voti;
 if ($num_giornata_file_voti == "SI") {
-#$num_giornata = ereg_replace("giornata","",$giornata);
+#$num_giornata = preg_replace("/giornata/","",$giornata);
 $num_giornata = $num_giornata + $diff_num_giornata_file;
 if ($num_giornata_file_voti_doppio == "SI") {
 if (strlen($num_giornata) == 1) $num_giornata = "0".$num_giornata;
 } # fine if ($num_giornata_file_voti_doppio == "SI")
 $posizione_file .= "$num_giornata".$seconda_parte_pos_file_voti;
 } # fine if ($num_giornata_file_voti == "SI")
-echo "<form method=\"post\" action=\"giornata.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
@@ -272,11 +287,20 @@ echo "<form method=\"post\" action=\"giornata.php\">
  dal file <input type=\"text\" name=\"posizione_file\" value=\"$posizione_file\" size=\"65\">
 </form>";
 } # fine if ($prima_parte_pos_file_voti or...
-else echo "<center>Copia il file voti$num_giornata.txt nella cartella dati.</center><br>";
+else echo "<br>
+<form accept-charset=\"utf-8\" enctype=\"multipart/form-data\" method=\"post\" action=\"./giornata.php\"><div style=\"text-align: center;\">
+<input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"20000000\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
+<input type=\"hidden\" name=\"upload_file_voti\" value=\"SI\">
+Copia il file voti$num_giornata.txt nella cartella dati, oppure<br> fai l'upload del file dei voti:
+<input name=\"file_voti_upload\" type=\"file\"><input class=\"sbutton\" type=\"submit\" value=\"invia\">.
+</div></form><br>";
 } # fine else if (@is_file("$percorso_cartella_dati/voti$num_giornata.txt"))
 } # fine else if ($voti_esistenti == "SI"))
 
-echo "<center><form method=\"post\" action=\"mercato.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
