@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 $parla = "NO";
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
@@ -35,19 +36,58 @@ else $giornata_ultima = $num1;
 $num_giornata_richiesta = substr($giornata,-2);
 if (!$giornata or $num_giornata_richiesta > $giornata_ultima) $giornata = "giornata$giornata_ultima";
 
-echo "<table width=\"100%\" align=\"center\"><tr><td width=\"33%\" align=\"left\">
-<form method=\"post\" action=\"guarda_giornata.php\">
+/*
+echo "<small>giornata: <a href=\"./giornata01.html\">01</a>
+<a href=\"./giornata02.html\">02</a>
+<a href=\"./giornata03.html\">03</a>
+<a href=\"./giornata04.html\">04</a>
+<a href=\"./giornata05.html\">05</a>
+<a href=\"./giornata06.html\">06</a>
+<a href=\"./giornata07.html\">07</a>
+<a href=\"./giornata08.html\">08</a>
+<a href=\"./giornata09.html\">09</a>
+<a href=\"./giornata10.html\">10</a>
+<a href=\"./giornata11.html\">11</a>
+<a href=\"./giornata12.html\">12</a>
+<a href=\"./giornata13.html\">13</a>
+<a href=\"./giornata14.html\">14</a>
+<a href=\"./giornata15.html\">15</a>
+<a href=\"./giornata16.html\">16</a>
+<a href=\"./giornata17.html\">17</a>
+<a href=\"./giornata18.html\">18</a>
+<a href=\"./giornata19.html\">19</a>
+<a href=\"./giornata20.html\">20</a>
+<a href=\"./giornata21.html\">21</a>
+<a href=\"./giornata22.html\">22</a>
+<a href=\"./giornata23.html\">23</a>
+<a href=\"./giornata24.html\">24</a>
+<a href=\"./giornata25.html\">25</a>
+<a href=\"./giornata26.html\">26</a>
+<a href=\"./giornata27.html\">27</a>
+<a href=\"./giornata28.html\">28</a>
+<a href=\"./giornata29.html\">29</a>
+<a href=\"./giornata30.html\">30</a>
+<a href=\"./giornata31.html\">31</a>
+<a href=\"./giornata32.html\">32</a>
+<br><br></small>";
+*/
+
+echo "<table width=\"100%\" align=\"center\"><tr>";
+#/*
+echo "<td width=\"33%\" align=\"left\">
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"guarda_giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
 <input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
- n <select name=\"giornata\">
+ n° <select name=\"giornata\">
 <option value=\"\">--</option>";
 for ($num1 = "01" ; $num1 <= $giornata_ultima ; $num1++) {
 if (strlen($num1) == 1) $num1 = "0".$num1;
 echo "<option value=\"giornata$num1\">$num1</option>";
 } # fine for $num1
 echo "</select></form></td>";
+#*/
 
 $tab_formazioni = "<tr>";
 $num_colonne = 0;
@@ -120,23 +160,28 @@ $num2 = 0;
 
 
 
-echo "<td align=\"center\"><b>$giornata</b><br><font size=\"-2\">$data</font></td>
-<td width=\"33%\" align=\"right\">
+echo "<td align=\"center\"><b>$giornata</b><br><font size=\"-2\">$data</font></td>";
+
+#/*
+echo "<td width=\"33%\" align=\"right\">
 <table><tr><td>
-<form method=\"post\" action=\"stat_campionato.php\">
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"stat_campionato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
 <input type=\"submit\" name=\"guarda_giornata\" value=\"Statistiche\">
 </form></td><td>
-<form method=\"post\" action=\"calendario.php\">
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"calendario.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"origine\" value=\"$origine\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
 <input type=\"submit\" name=\"guarda_giornata\" value=\"Calendario\">
-</form></td></tr></table></td></tr></table>";
+</form></td></tr></table></td>";
+#*/
+
+echo "</tr></table>";
 
 
 
@@ -167,7 +212,7 @@ $formazione = "formazione_$giocatore";
 $formazione = $$formazione;
 $num_linee_formazione = count($formazione);
 for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
-$formazione[$num2] = ereg_replace(" ","_",$formazione[$num2]);
+$formazione[$num2] = preg_replace("/ /","&nbsp;",$formazione[$num2]);
 $tab_formazioni .= $formazione[$num2]."<br>";
 } # fine for $num2
 $tab_formazioni .= "</td>
@@ -249,7 +294,7 @@ echo "</td>";
 
 # calcolo la classifica fino a questa giornata
 if ($tipo_campionato != "N") {
-$punti = "";
+$punti = array();
 for ($num1 = $g_inizio_campionato ; $num1 <= $num_giornata ; $num1++) {
 if (strlen($num1) == 1) $num1 = "0".$num1;
 $giornata_punti = "giornata$num1";
@@ -291,15 +336,28 @@ echo $nome_sqadra_memo[$key].": $val<br>";
 echo "</td>";
 } # fine if ($tipo_campionato != "N")
 echo "</tr></table>";
-echo "<br><center>Giornata chiusa.</center><br>";
+
+#/*
+echo "<br><center>Giornata chiusa.</center>";
+#*/
+
 } # fine if ($voti_esistenti == "SI")
 
 if ($target) $target = " target=\"$target\"";
 if (!$origine) $origine = "mercato.php";
-echo "<center><form method=\"post\" action=\"$origine\"$target>
-<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
-<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
+
+/*
+$origine = "../index.html";
+*/
+
+echo "<br><center><form  accept-charset=\"utf-8\" method=\"post\" action=\"$origine\"$target>";
+
+#/*
+echo "<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
+#*/
+
+echo "<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
 </form></center>";
 
 
