@@ -20,6 +20,8 @@
 ##################################################################################
 
 
+
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -33,10 +35,11 @@ if ($stato_mercato == "C") echo "<br><font size=-1>(chiuso)</font>";
 if ($stato_mercato == "S") echo "<br><font size=-1>(sospeso)</font>";
 echo "</center>
 <table align=\"center\"><tr>
-<td><form method=\"post\" action=\"tab_calciatori.php\">
+<td><form  accept-charset=\"utf-8\" method=\"post\" action=\"tab_calciatori.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-<input type=\"submit\" name=\"tab_calciatori\" value=\"Guarda tutti\">
+<input type=\"hidden\" name=\"tab_calciatori\" value=\"Guarda tutti\">
+<input type=\"submit\" value=\"Guarda tutti\">
 <select name=\"ruolo_guarda\">
 <option value=\"tutti\">i calciatori</option>
 <option value=\"P\">i portieri</option>
@@ -45,10 +48,11 @@ echo "</center>
 if ($considera_fantasisti_come != "P" and $considera_fantasisti_come != "D" and $considera_fantasisti_come != "C" and $considera_fantasisti_come != "A") echo "<option value=\"F\">i fantasisti</option>";
 echo "<option value=\"A\">gli attaccanti</option>
 </select>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>
-<td><form method=\"post\" action=\"squadra.php\">
+<td><form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-<input type=\"submit\" name=\"guarda_squadra\" value=\"Guarda la squadra\">
+<input type=\"hidden\" name=\"guarda_squadra\" value=\"Guarda la squadra\">
+<input type=\"submit\" value=\"Guarda la squadra\">
  <select name=\"nome_squadra\">
 <option value=\"tutti\">di tutti</option>";
 $num_giocatori=count($pass);
@@ -66,11 +70,12 @@ echo "</select>&nbsp;&nbsp;&nbsp;&nbsp;</form></td></tr><tr>
 <td align=\"center\" colspan=\"2\">
 <table align=\"center\" width=\"100%\"><tr>";
 if ($mostra_giornate_in_mercato == "SI") {
-echo "<td align=\"center\"><form method=\"post\" action=\"guarda_giornata.php\">
+echo "<td align=\"center\"><form  accept-charset=\"utf-8\" method=\"post\" action=\"guarda_giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
-<input type=\"submit\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
- n <select name=\"giornata\">
+<input type=\"hidden\" name=\"guarda_giornata\" value=\"Guarda la giornata\">
+<input type=\"submit\" value=\"Guarda la giornata\">
+ n&deg; <select name=\"giornata\">
 <option value=\"\">--</option>";
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
 if (strlen($num1) == 1) $num1 = "0".$num1;
@@ -100,7 +105,7 @@ $sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) -
 if ($sec_restanti > 0) $richiesto = "SI";
 } # fine if ($nome_utente == $dati_scambio[4])
 } # fine for $num1
-echo "<td align=\"center\"><form method=\"post\" action=\"scambi_proposti.php\">
+echo "<td align=\"center\"><form  accept-charset=\"utf-8\" method=\"post\" action=\"scambi_proposti.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
 if ($richiesto == "SI") echo "<font color=\"red\"><b>> </b></font>";
@@ -108,7 +113,7 @@ echo "<input type=\"submit\" name=\"guarda_scambi\" value=\"Proposte di scambio\
 if ($richiesto == "SI") echo "<font color=\"red\"><b> <</b></font>";
 echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</form></td>";
 } # fine if ($num_calciatori_scambiabili > 0)
-echo "<td align=\"center\"><form method=\"post\" action=\"messaggi.php\">
+echo "<td align=\"center\"><form  accept-charset=\"utf-8\" method=\"post\" action=\"messaggi.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"guarda_messaggi\" value=\"Messaggi\">
@@ -119,7 +124,17 @@ echo "<td align=\"center\"><form method=\"post\" action=\"messaggi.php\">
 $calciatori = @file("$percorso_cartella_dati/mercato.txt");
 $num_calciatori = count($calciatori);
 
-echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
+if ($formato_pda == "SI") echo "
+<table width=3 border=1 cellspacing=0 cellpadding=1 align=\"center\" bgcolor=\"$sfondo_tab\">
+<tr><td><font size=-2>Num.</font></td>
+<td>__________Nome__________</td>
+<td><font size=-2>Ruolo</font></td>
+<td><font size=-2>Costo</font></td>
+<td><font size=-1>Proprietario</font></td>
+<td><font size=-2>Tempo rimasto</font></td>
+<td>&nbsp;</td></tr>";
+else echo "
+<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
 <tr><td><font size=-2>Num.</font></td>
 <td>_____________Nome_____________</td>
 <td><font size=-2>Ruolo</font></td>
@@ -158,8 +173,23 @@ $minuto_off = substr($tempo_off,10,2);
 $sec_restanti = mktime($ora_off,$minuto_off,0,$mese_off,$giorno_off,$anno_off) - $adesso;
 if ($sec_restanti < 0) {
 $tempo_restante = "COMPRATO";
-if ($nome_utente == $proprietario) $offri = "<a href=\"vendi.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">vendi</a>";
-else $offri = "<font size=-2><a href=\"scambia.php?num_calciatore=$numero&altro_utente=$proprietario&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">scambia</a></font>";
+if ($nome_utente == $proprietario) $offri = "<a href=\"vendi.php?num_calciatore=$numero&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">vendi</a>";
+else $offri = "<font size=-2><a href=\"scambia.php?num_calciatore=$numero&amp;altro_utente=$proprietario&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">scambia</a></font>";
+if ($formato_pda == "SI") {
+if ($nome_utente == $proprietario) $offri = "<form  accept-charset=\"utf-8\" method=\"post\" action=\"vendi.php\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"hidden\" name=\"num_calciatore\" value=\"$numero\">
+<input type=\"submit\" value=\"vendi\">
+</form>";
+else $offri = "<form  accept-charset=\"utf-8\" method=\"post\" action=\"scambia.php\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"hidden\" name=\"altro_utente\" value=\"$proprietario\">
+<input type=\"hidden\" name=\"num_calciatore\" value=\"$numero\">
+<input type=\"submit\" value=\"scambia\">
+</form>";
+} # fine if ($formato_pda == "SI")
 $tab_comprati .= "<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
@@ -176,7 +206,15 @@ $tempo_restante = "";
 if ($giorni_restanti > 0) { $tempo_restante = "$giorni_restanti giorni "; }
 if ($ore_restanti > 0) { $tempo_restante .= "$ore_restanti h. "; }
 $tempo_restante .= "$minuti_restanti m.";
-$offri = "<a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a>";
+$offri = "<a href=\"offerta.php?num_calciatore=$numero&amp;nome_utente=$nome_utente&amp;pass_fornita=$pass_fornita\">offri</a>";
+if ($formato_pda == "SI") {
+$offri = "<form  accept-charset=\"utf-8\" method=\"post\" action=\"offerta.php\">
+<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
+<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
+<input type=\"hidden\" name=\"num_calciatore\" value=\"$numero\">
+<input type=\"submit\" value=\"offri\">
+</form>";
+} # fine if ($formato_pda == "SI")
 if (togli_acapo($dati_calciatore[6]) != "###PRIMA_OFFERTA###") {
 $vecchio_proprietario = $dati_calciatore[6];
 $nuovo_costo = $dati_calciatore[8];
@@ -191,7 +229,7 @@ if ($vecchio_proprietario) { $proprietario_mostra = "$proprietario <font size=-2
 else { $proprietario_mostra = $proprietario; }
 if ($nuovo_costo) { $costo_mostra = $nuovo_costo; }
 else { $costo_mostra = $costo; }
-if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= "<font size=-2>&nbsp;(1)</font>";
+if ($prima_offerta == "SI" and $min_rilancio_dopo_offerta_iniziale != 1) $proprietario_mostra .= "<font size=-2>&nbsp;(1&deg;)</font>";
 $sec_restanti_vett[$numero] = $sec_restanti;
 $riga_tab_mercato[$numero] = "<tr><td>$numero</td>
 <td>$nome</td>
@@ -228,12 +266,12 @@ Numero di calciatori ancora comperabili: <b>$num_calciatori_comprabili</b>.</cen
 
 if ($pass_admin_errata == "NO") {
 echo "<center>Benvenuto admin!<br><br>
-<form method=\"post\" action=\"configura.php\">
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"./configura.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"vai_a_configura\" value=\"Configura Fantacalciobazar\">
 </form><br>";
-echo "<form method=\"post\" action=\"giornata.php\">
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./giornata.php\"><div>
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">";
 for ($num1 = "01" ; $num1 < 100 ; $num1++) {
@@ -249,19 +287,19 @@ echo "<br>";
 $pulsanti = 0;
 } # fine if ($pulsanti == 5)
 } # fine for $num1
-echo "</form>
-<form method=\"post\" action=\"./crea_giornata.php\">
+echo "</div></form>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_giornata.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
 <input type=\"submit\" name=\"crea_giornata\" value=\"Crea la giornata $num1\">
 </form><br><br>
-<form method=\"post\" action=\"./crea_sondaggio.php\">
+<form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_sondaggio.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"vai\" value=\"Sondaggi-Votazioni\">
 </form>
-<form method=\"post\" action=\"./messaggi.php\">
+<form  accept-charset=\"utf-8\" method=\"post\" action=\"./messaggi.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"vai\" value=\"Messaggi\">
