@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    FANTACALCIOBAZAR
-#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
+#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marcods@gmx.net)
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -117,6 +117,8 @@ $trovato = "SI";
 $nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
 $nome = togli_acapo($nome);
 $nome = str_replace("\"","",$nome);
+if ($num_colonna_attributo_fantasista) $attr_fantasista = $dati_calciatore[($num_colonna_attributo_fantasista-1)];
+else $attr_fantasista = 0;
 $s_ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
 $s_ruolo = togli_acapo($s_ruolo);
 $ruolo = $s_ruolo;
@@ -126,6 +128,7 @@ if ($s_ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
 if ($s_ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
 if ($s_ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
 if ($s_ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";
+if ($considera_fantasisti_come == "F" and $attr_fantasista) $ruolo = "F";
 echo"<tr><td>$numero</td>
 <td>$nome</td>
 <td>$ruolo</td>
