@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -97,7 +98,7 @@ echo "Hai offerto un calciatore non in tuo possesso!<br>";
 } # fine if ($calciatori_utente[$calciatore_scambio_utente] != "SI" and...
 if ($gia_offerti_utente[$calciatore_scambio_utente] == "SI") {
 $scambiare = "NO";
-echo "Hai offerto pi volte lo stesso calciatore.<br>";
+echo "Hai offerto più volte lo stesso calciatore.<br>";
 } # fine if ($gia_offerti_utente[$calciatore_scambio_utente] == "SI")
 if ($calciatore_scambio_utente != "") {
 if ($num_calciatori_offerti > 0) $lista_off .= ";$calciatore_scambio_utente";
@@ -113,7 +114,7 @@ echo "Hai richiesto un calciatore non posseduto da $altro_utente!<br>";
 } # fine if ($calciatori_altro[$calciatore_scambio_altro] != "SI" and...
 if ($gia_offerti_altro[$calciatore_scambio_altro] == "SI") {
 $scambiare = "NO";
-echo "Hai richiesto pi volte lo stesso calciatore.<br>";
+echo "Hai richiesto più volte lo stesso calciatore.<br>";
 } # fine if ($gia_offerti_altro[$calciatore_scambio_altro] == "SI")
 if ($calciatore_scambio_altro != "") {
 if ($num_calciatori_richiesti > 0) $lista_ric .= ";$calciatore_scambio_altro";
@@ -135,16 +136,16 @@ echo "Non hai richiesto nessun calciatore.<br>";
 $num_calciatori_dopo = $num_calciatori_posseduti + $num_calciatori_richiesti - $num_calciatori_offerti;
 if ($num_calciatori_dopo > $max_calciatori) {
 $scambiare = "NO";
-echo "Dopo lo scambio avresti pi di $max_calciatori calciatori.<br>";
+echo "Dopo lo scambio avresti più di $max_calciatori calciatori.<br>";
 } # fine if ($num_calciatori_dopo > $max_calciatori)
 
 if ($nome_utente == $altro_utente) {
 $scambiare = "NO";
-echo "Hai una doppia personalit?.<br>";
+echo "Hai una doppia personalità?.<br>";
 } # fine if ($nome_utente == $altro_utente)
 
-$verifica_num = ereg_replace("[0-9]","",$soldi_scambio_utente);
-$verifica_num_altro = ereg_replace("[0-9]","",$soldi_scambio_altro);
+$verifica_num = preg_replace("/[0-9]/","",$soldi_scambio_utente);
+$verifica_num_altro = preg_replace("/[0-9]/","",$soldi_scambio_altro);
 if ($verifica_num != "" or $verifica_num_altro != "") {
 $scambiare = "NO";
 echo "I Fanta-Euro devono essere un numero intero.<br>";
@@ -155,14 +156,14 @@ $surplus = $surplus[0];
 $soldi_spendibili = $soldi_iniziali + $surplus - $soldi_spesi;
 if ($soldi_scambio_utente > $soldi_spendibili) {
 $scambiare = "NO";
-echo "Hai offerto pi soldi di quelli da te posseduti.<br>";
+echo "Hai offerto più soldi di quelli da te posseduti.<br>";
 } # fine if ($soldi_scambio_utente > $soldi_spendibili)
 $surplus_altro = @file("$percorso_cartella_dati/squadra_$altro_utente");
 $surplus_altro = $surplus_altro[0];
 $soldi_spendibili_altro = $soldi_iniziali + $surplus_altro - $soldi_spesi_altro;
 if ($soldi_scambio_altro > $soldi_iniziali) {
 $scambiare = "NO";
-echo "Hai richiesto a $altro_utente pi soldi di quelli iniziali.<br>";
+echo "Hai richiesto a $altro_utente più soldi di quelli iniziali.<br>";
 } # fine if ($soldi_scambio_utente > $soldi_spendibili)
 
 if ($scambiare != "NO") {
@@ -191,7 +192,7 @@ if ($sec_restanti > 0) $num_offerte_utente++;
 } # fine for $num1
 if ($num_offerte_utente >= 12) {
 $scambiare = "NO";
-echo "Hai gi in corso 12 offerte di scambio.<br>";
+echo "Hai già in corso 12 offerte di scambio.<br>";
 } # fine if ($num_offerte_utente >= 12)
 
 # finalmente dopo tutti i controlli inserisco lo scambio
@@ -211,7 +212,7 @@ $linea = "$id_scambio,$nome_utente,$lista_off,$soldi_scambio_utente,$altro_utent
 fwrite($file_scambi,"$linea
 ");
 for ($num1 = 0 ; $num1 < $num_scambi_proposti ; $num1++) {
-# se lo scambio  scaduto non lo riscrivo
+# se lo scambio è scaduto non lo riscrivo
 $dati_scambio = explode(",", $scambi_proposti[$num1]);
 $tempo_off = $dati_scambio[7];
 $tempo_off = togli_acapo($tempo_off);
@@ -226,7 +227,7 @@ if ($sec_restanti > 0) fwrite($file_scambi,$scambi_proposti[$num1]);
 } # fine for $num1
 flock($file_scambi,3);
 fclose($file_scambi);
-echo "L'offerta di scambio  stata inviata!<br>";
+echo "L'offerta di scambio è stata inviata!<br>";
 } # fine if ($scambiare != "NO")
 
 flock($lock,3);
@@ -239,7 +240,7 @@ if ($scambiare == "NO") echo "Scambio non permesso.<br>";
 else {
 
 
-echo "<form method=\"post\" action=\"scambia.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"scambia.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"altro_utente\" value=\"$altro_utente\">
@@ -290,7 +291,7 @@ echo "<center>
 } # fine else if ($num_calciatori_scambiabili == 0)
 
 
-echo "<br><br><center><form method=\"post\" action=\"mercato.php\">
+echo "<br><br><center><form  accept-charset=\"utf-8\" method=\"post\" action=\"mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
