@@ -19,6 +19,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ##################################################################################
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 if ($pass_errata != "SI") {
 
@@ -67,7 +68,7 @@ $$nome_num_titolari++;
 if ($$nome_schierato == "panchinaro") {
 $num_in_panchina = "panchinaro$numero";
 $num_in_panchina = $$num_in_panchina;
-$verifica_num = ereg_replace("[0-9]","",$num_in_panchina);
+$verifica_num = preg_replace("/[0-9]/","",$num_in_panchina);
 if ($verifica_num != "" or $num_in_panchina > $max_in_panchina) {
 $inserire = "NO";
 $frase = "Si deve inserire la posizione del calciatore in panchina.<br>";
@@ -97,11 +98,11 @@ if ($num_titolari_F != 0) $schema = $num_titolari_P.$num_titolari_D.$num_titolar
 $schema_trovato = "NO";
 if ($num_titolari > 11) {
 $inserire = "NO";
-$frase .= "Hai schierato pi di 11 calciatori!<br>";
+$frase .= "Hai schierato più di 11 calciatori!<br>";
 } # fine if ($num_titolari > 11)
 if ($num_panchinari > $max_in_panchina) {
 $inserire = "NO";
-$frase .= "Hai schierato pi di $max_in_panchina calciatori in panchina!<br>";
+$frase .= "Hai schierato più di $max_in_panchina calciatori in panchina!<br>";
 } # fine if ($num_panchinari > $max_in_panchina)
 if ($num_titolari == 11) {
 $num_schemi = count($schemi);
@@ -176,23 +177,25 @@ else echo "<b>ERRORE</b> di scrittura.<br>";
 flock($lock,3);
 fclose($lock);
 echo "<html>
-<header>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> fantacalcio </title>
 <meta http-equiv=\"refresh\" content=\"1; url=squadra.php?nome_squadra=$nome_utente&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">
-</header>
+</head>
 <body bgcolor=#ffffff>
 Squadra cambiata!";
 } # fine if ($inserire != "NO")
 else {
 echo "<html>
-<header>
+<head>
+<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <title> Fantacalcio </title>
-</header>
+</head>
 <body bgcolor=#ffffff>
 $frase";
 } # fine else if ($inserire != "NO")
 
-echo "<center><form method=\"post\" action=\"squadra.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
