@@ -20,6 +20,7 @@
 ##################################################################################
 
 
+include('./include/funzioni.php');
 include("./controlla_pass.php");
 include("$percorso_cartella_dati/head.php");
 if ($pass_errata != "SI") {
@@ -61,11 +62,11 @@ echo "Non puoi vendere questo calciatore.<br>";
 } # fine if ($trovato == "NO")
 
 else {
-if ($stato_mercato == "S") echo "<center>Il mercato  <b>sospeso</b> in questo momento.</center><br>";
-if ($stato_mercato == "C") echo "<center>Il mercato  <b>chiuso</b> in questo momento.</center><br>";
+if ($stato_mercato == "S") echo "<center>Il mercato è <b>sospeso</b> in questo momento.</center><br>";
+if ($stato_mercato == "C") echo "<center>Il mercato è <b>chiuso</b> in questo momento.</center><br>";
 else {
 $prezzo_vendita = floor(($costo/100)*$percentuale_vendita);
-echo "<form method=\"post\" action=\"vendi_subito.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"vendi_subito.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
@@ -73,7 +74,7 @@ echo "<form method=\"post\" action=\"vendi_subito.php\">
  il calciatore <b>$nome</b> per <b>$prezzo_vendita</b> Fanta-Euro (comprato a <b>$costo</b> Fanta-Euro).<br>
 </form>";
 if ($stato_mercato != "S") {
-echo "<form method=\"post\" action=\"vendi_sul_mercato.php\">
+echo "<form  accept-charset=\"utf-8\" method=\"post\" action=\"vendi_sul_mercato.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"num_calciatore\" value=\"$num_calciatore\">
@@ -85,7 +86,7 @@ echo "<form method=\"post\" action=\"vendi_sul_mercato.php\">
 } # fine else if ($stato_mercato == "C")
 } # fine else if ($trovato == "NO")
 
-echo "<center><form method=\"post\" action=\"squadra.php\">
+echo "<center><form  accept-charset=\"utf-8\" method=\"post\" action=\"squadra.php\">
 <input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
 <input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
 <input type=\"hidden\" name=\"nome_squadra\" value=\"$nome_utente\">
